#!/usr/bin/env python3

"""
Helper file to generate a simple C header with a given color palette from
Matplotlib
"""

from matplotlib import cm
import argparse
import sys

def rgb_to_int(r, g, b, a=255):
    """Convert a tuple of three values, RGB, to a single number RGBA"""
    return (a << 24) + (r << 16) + (g << 8) + b

# Create command line parsers for optional arguments
parser = argparse.ArgumentParser()
parser.add_argument('--palette', default='viridis', help="Color palette to generate")
parser.add_argument('--output', default='include/utils/palette.h', help="Output file")

args = parser.parse_args()
# Try to extract color map
palette = cm.get_cmap(args.palette)
if not palette:
    sys.exit(f"'{args.palette}' not a valid color map in Matplotlib")
# Write color map to header
with open(args.output, 'w') as fil:
    fil.write("#pragma once\n")
    fil.write("\n")
    fil.write("// This file was autogenerated, changes will be overwritten!\n")
    fil.write("\n")
    fil.write("#include <stdint.h>\n")
    fil.write("\n")
    fil.write(f"static const uint32_t palette_size = {len(palette.colors)};\n")
    fil.write("static const uint32_t palette[] = {\n")
    for r, g, b in palette.colors:
        val = rgb_to_int(int(r * 255.), int(g * 255.), int(b * 255.))
        fil.write(f"\t{val},\n")
    fil.write("};")
